@@ -4,6 +4,7 @@
 struct auth_request;
 
 struct auth_stream_reply *auth_stream_reply_init(pool_t pool);
+struct auth_stream_reply *auth_stream_reply_init_userdb(pool_t pool);
 void auth_stream_reply_add(struct auth_stream_reply *reply,
 			   const char *key, const char *value);
 void auth_stream_reply_reset(struct auth_stream_reply *reply);
@@ -11,6 +12,7 @@ void auth_stream_reply_remove(struct auth_stream_reply *reply, const char *key);
 
 const char *auth_stream_reply_find(struct auth_stream_reply *reply,
 				   const char *key);
+bool auth_stream_reply_exists(struct auth_stream_reply *reply, const char *key);
 
 void auth_stream_reply_import(struct auth_stream_reply *reply, const char *str);
 const char *auth_stream_reply_export(struct auth_stream_reply *reply);
